.. Authanor documentation master file, created by
   sphinx-quickstart on Sat May  6 11:00:00 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Authanor
========

A tool providing a a Pythonic interface to SQLAlchemy while enforcing authorization criteria for Flask.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api/modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
